@@ -19,7 +19,7 @@
 #ifndef CACHE_H
 #define CACHE_H
 
-#include "eniro.h"
+#include "source.h"
 
 class Cache
 {
@@ -27,8 +27,8 @@ class Cache
 public:
     static Cache& instance();
     int clear();
-    bool findItem(QString const& number, Eniro::Result& result);
-    bool addItem(Eniro::Result const& result);
+    bool findItem(QString const& number, Source::Result& result);
+    bool addItem(Source::Result const& result);
 
 private:
     Cache();
