@@ -406,7 +406,7 @@ void ConnectionManager::scanResult(const QDBusMessage& rep)
         {
             if(status == ICD_SCAN_NEW)
             {
-                connections_->insert(i, connection);
+                connections_->replace(i, connection);
             }
 
             return;
