@@ -27,18 +27,20 @@
 
 namespace
 {
-    static int const LANGUAGE_COUNT = 3;
+    static int const LANGUAGE_COUNT = 4;
 
     static QString const LANGUAGE_NAMES[LANGUAGE_COUNT] = {
        "English",
        "Norsk",
-       "Suomi"
+       "Suomi",
+       "Svenska"
     };
 
     static QString const LANGUAGE_IDS[LANGUAGE_COUNT] = {
        "en_US",
        "nb_NO",
-       "fi_FI"
+       "fi_FI",
+       "sv_SE"
     };
 }
 
