@@ -29,7 +29,7 @@
     </message>
     <message>
         <source>Automatic connecting is not allowed by settings.</source>
-        <translation>Automatisk oppkobling ikke tillatt, sjekk innstillinger.</translation>
+        <translation>Automatisk oppkobling ikke tillatt, sjekk innstillingene.</translation>
     </message>
     <message>
         <source>Connecting...</source>
@@ -68,7 +68,7 @@
     <message>
         <location filename="../../gui/connectionselector.cpp" line="72"/>
         <source>Any connection</source>
-        <translation>Vilkårlig tilkobling</translation>
+        <translation>Alle tilkoblinger</translation>
     </message>
 </context>
 <context>
@@ -77,7 +77,7 @@
         <location filename="../../gui/detailwindow.cpp" line="42"/>
         <location filename="../../gui/detailwindow.cpp" line="119"/>
         <source>Add to contacts</source>
-        <translation>Legg til kontakter</translation>
+        <translation>Legg til i kontakter</translation>
     </message>
     <message>
         <location filename="../../gui/detailwindow.cpp" line="43"/>
@@ -158,7 +158,7 @@
     <message>
         <location filename="../../gui/emptyguiconfig.cpp" line="27"/>
         <source>Selected phonebook has no settings to configure.</source>
-        <translation>Den valgte telefonlisten har ingen innstillinger.</translation>
+        <translation>Den valgte telefonkatalogen har ingen innstillinger.</translation>
     </message>
 </context>
 <context>
@@ -205,13 +205,13 @@
         <location filename="../../gui/mainwindow.cpp" line="54"/>
         <location filename="../../gui/mainwindow.cpp" line="151"/>
         <source>Stop daemon</source>
-        <translation>Stopp daemon</translation>
+        <translation>Stopp autosøk</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="60"/>
         <location filename="../../gui/mainwindow.cpp" line="117"/>
         <source>Start daemon</source>
-        <translation>Start daemon</translation>
+        <translation>Start autosøk</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="65"/>
@@ -231,22 +231,22 @@
     <message>
         <location filename="../../gui/mainwindow.cpp" line="115"/>
         <source>Daemon was successfully stopped.</source>
-        <translation>Daemon ble stoppet.</translation>
+        <translation>Autosøk ble stoppet.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="116"/>
         <source>Unable to stop daemon.</source>
-        <translation>Kan ikke stoppe daemon.</translation>
+        <translation>Kan ikke stoppe Autosøk.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="127"/>
         <source>Unable to start daemon</source>
-        <translation>Kan ikke starte daemon.</translation>
+        <translation>Kan ikke starte autosøk.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="129"/>
         <source>Daemon cannot be started because it&apos;s not allowed to connect to the Internet. You have to either allow automatic Internet connection in Jenirok settings or in global Maemo settings.</source>
-        <translation>Daemon får ikke tilgang til internett. Du må enten tillate automatisk tilkobling til internett i Jenirok eller i globale Maemo innstillinger.</translation>
+        <translation>Autosøk får ikke tilgang til internett. Du må enten tillate automatisk oppkobling til internett i Jenirok eller i globale Maemo innstillinger.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="133"/>
@@ -261,12 +261,12 @@
     <message>
         <location filename="../../gui/mainwindow.cpp" line="149"/>
         <source>Daemon was successfully started.</source>
-        <translation>Daemon ble startet.</translation>
+        <translation>Autosøk ble startet.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="150"/>
         <source>Unable to start daemon.</source>
-        <translation>Kan ikke starte daemon.</translation>
+        <translation>Kan ikke starte autosøk.</translation>
     </message>
     <message>
         <location filename="../../gui/mainwindow.cpp" line="157"/>
@@ -333,7 +333,7 @@
     <message>
         <location filename="../../gui/searchdialog.cpp" line="33"/>
         <source>Name/number</source>
-        <translation>Navn/nummer</translation>
+        <translation>Navn/Nummer</translation>
     </message>
     <message>
         <location filename="../../gui/searchdialog.cpp" line="39"/>
@@ -379,7 +379,7 @@
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="61"/>
         <source>Clear</source>
-        <translation>Tilbakestill</translation>
+        <translation>Tøm</translation>
     </message>
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="64"/>
@@ -394,7 +394,7 @@
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="82"/>
         <source>Phonebook</source>
-        <translation>Kontaktliste</translation>
+        <translation>Telefonkatalog</translation>
     </message>
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="102"/>
@@ -424,23 +424,23 @@
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="137"/>
         <source>General</source>
-        <translation>Generell</translation>
+        <translation>Generelt</translation>
     </message>
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="138"/>
         <source>Daemon</source>
-        <translation>Daemon</translation>
+        <translation>Autosøk</translation>
     </message>
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="139"/>
         <location filename="../../gui/settingsdialog.cpp" line="208"/>
         <source>Phonebook settings</source>
-        <translation>Kontaktliste innstillinger</translation>
+        <translation>Telefonkatalog innst.</translation>
     </message>
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="170"/>
         <source>Restarting daemon...</source>
-        <translation>Restarter daemon...</translation>
+        <translation>Restarter Autosøk...</translation>
     </message>
     <message>
         <location filename="../../gui/settingsdialog.cpp" line="176"/>
