@@ -60,8 +60,10 @@ bool CallListener::begin()
     }
 
     sourceId_ = Source::stringToId(Settings::instance()->get("source"));
+    QMap<QString, QString> tmpConfig;
     SourceCoreConfig* config = SourceCoreConfig::getCoreConfig(sourceId_);
-    config->getConfig(sourceConfig_);
+    config->getConfig(tmpConfig);
+    sourceConfig_ = tmpConfig;
     delete config;
 
     systemBus_.connect(CALL_SERVICE_NAME,
