@@ -21,12 +21,19 @@
 
 #include <QtCore/QMap>
 #include <QtCore/QString>
+#include <QtCore/QVariant>
 #include <QtGui/QDialog>
 #include <QtGui/QWidget>
 #include <QtGui/QLineEdit>
+#include <QtGui/QCheckBox>
+#include <QtGui/QTabWidget>
 #include <QMaemo5ListPickSelector>
-#include "eniro.h"
-#include "buttonselector.h"
+#include "source.h"
+
+class SourceGuiConfig;
+class ButtonSelector;
+class ConnectionSelector;
+
 
 class SettingsDialog : public QDialog
 {
@@ -37,18 +44,22 @@ public:
 
 public slots:
     void saveSettings();
-    void setVisible(bool visible);
     void resetCache();
 
+private slots:
+    void onSourceSelected(unsigned int index, QString const& text, QVariant const& value);
+
 private:
-    static QMap <Eniro::Site, Eniro::SiteDetails> sites_;
-    QLineEdit* usernameInput_;
-    QLineEdit* passwordInput_;
+    static QList<Source::SourceDetails> sources_;
+    SourceGuiConfig* sourceConfig_;
     QLineEdit* cacheInput_;
-    ButtonSelector* siteSelector_;
+    ButtonSelector* languageSelector_;
+    ButtonSelector* sourceSelector_;
     ButtonSelector* autostartSelector_;
-    QString currentSite_;
-    QString currentAutostart_;
+    ConnectionSelector* connectionSelector_;
+    QString currentSource_;
+    QString selectedLanguage_;
+    QTabWidget* tabs_;
 };
 
 #endif
